function object = ctrl_adaptive()

% object = ctrl_adaptive()
%
% The adaptive controller inherited from ctrl_basic.
%
% Valid fields in settings:
%   .init_groups   Settings for the 'init_groups' method. This method is not
%                  overridden here, see the help section of ctrl_basic for
%                  details.
%   .tune_groups   Settings for the 'tune_groups' method. This method is
%                  overridden here, see its help section for details.
%
%
% tune_groups:
%
% The given stop trigger is started, and the grouping is tuned until the
% trigger activates. On each tune iteration all IVGA primitive operations are
% run with adaptively changing probabilities.


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


% $Id: ctrl_adaptive.m,v 1.8 2006/04/12 17:32:01 pwagner Exp $
% $Name: ivga-1_14_7 $

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global STATS State;


% register stats operations
STATS = add_operation( STATS, 'init_groups', {}, 'print', {} );
STATS = add_operation( ...
    STATS, 'tune_groups', ...
    { 'group count', 'stop trigger level', 'memory usage', ...
      'pr_Reinit_model', 'pr_Improve_model', 'pr_Move_var', ...
      'pr_Merge', 'pr_Split', ...
      'share_Reinit_model', 'share_Improve_model', 'share_Move_var', ...
      'share_Merge', 'share_Split', 'stationary variable sweeps', ...
      'iteration' }, ...
    'print', { 'group count', 'stop trigger level', ...
               'pr_Reinit_model', 'pr_Improve_model', ...
               'pr_Move_var', 'pr_Merge', 'pr_Split', ...
               'stationary variable sweeps', 'iteration' } );
STATS = add_operation( STATS, ...
                       'init_groups - Reinit_model', {'stop trigger level'} );
STATS = add_operation( STATS, ...
                       'init_groups - Improve_model', {'stop trigger level'} );


% create the object (inherit from ctrl_basic, no new data fields)
STATS = set_active( STATS, 0 );    % don't inherit op entries
object = class( struct([]), 'ctrl_adaptive', ctrl_basic );
STATS = set_active( STATS, 'revert' );
return;
