function object = ctrl_basic()

% object = ctrl_basic()
%
% The non-adaptive basic controller. It is started with method 'run', which
% takes a settings structure and uses global State and STATS. The output is
% left in global variables State and STATS.
%
% If the State doesn't have any active groups, then some variables are
% thrown in with 'init_groups' method. The amount of variables is controlled
% in init_group's settings. If the State has some active groups, then this
% phase is skipped.
% 
% Finally the grouping in State is tuned with method 'tune_groups'.
%
%
% init_groups:
%
% An own group is created and activated for each variable that is added. Its
% model is tuned according to the init_groups settings.
%
%
% tune_groups:
%
% The given stop trigger is started, and the grouping is tuned until the
% trigger activates. On each tune iteration all IVGA primitive operations are
% run with a probability defined in the tune_groups settings.


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


% $Id: ctrl_basic.m,v 1.3 2006/04/12 17:32:01 pwagner Exp $
% $Name: ivga-1_14_7 $

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global STATS State;


% register stats operations
STATS = add_operation( STATS, 'init_groups', {}, 'print', {} );
STATS = add_operation( ...
    STATS, 'tune_groups', ...
    { 'group count', 'stop trigger level', ...
      'stationary variable sweeps', 'iteration' }, ...
    'print', { 'group count', 'stop trigger level', ...
               'stationary variable sweeps', 'iteration' } );
STATS = add_operation( STATS, ...
                       'init_groups - Reinit_model', {'stop trigger level'} );
STATS = add_operation( STATS, ...
                       'init_groups - Improve_model', {'stop trigger level'} );


% declare the data fields of the object
this.dummy = [];

% create the object
object = class( this, 'ctrl_basic' );


return;
